@@ -1,14 +1,9 @@
 package Tapper::Test;
-# git description: v4.1.1-1-g2583c93
+# git description: v4.1.2-3-g0257452
 
-BEGIN {
-  $Tapper::Test::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Test::VERSION = '4.1.2';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Utilities for Perl based Tapper testing
-
+$Tapper::Test::VERSION = '5.0.0';
 use warnings;
 use strict;
 
@@ -217,9 +212,10 @@ sub tapper_section_meta
 1; # End of Tapper::Test
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -248,17 +244,26 @@ Provides general meta information applying to the whole report.
 
 Provides meta information allowed to be repeated in several sections.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
